@@ -4,10 +4,11 @@ As you know, every app must be hooked into yout main ``urls.py`` so that
 you can actually reach the app's views (provided it has any views, of course).
 
 """
-from django.conf.urls.defaults import include, patterns, url
+from django.conf.urls import include, patterns, url
 from django.contrib import admin
+from django.contrib.auth.models import User
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
-from django.views.generic import TemplateView
+from django.views.generic import ListView
 
 admin.autodiscover()
 
@@ -16,7 +17,7 @@ urlpatterns = patterns(
     '',
     url(r'^admin/', include(admin.site.urls)),
     url(r'^feedback/', include('feedback_form.urls')),
-    url(r'^test/$', TemplateView.as_view(template_name='base.html')),
+    url(r'^$', ListView.as_view(model=User, template_name='base.html')),
 )
 
 urlpatterns += staticfiles_urlpatterns()
